@@ -1,7 +1,6 @@
 package Mojo::Transaction::WebSocket;
 use Mojo::Base 'Mojo::Transaction';
 
-use Compress::Raw::Zlib 'Z_SYNC_FLUSH';
 use Config;
 use Mojo::JSON;
 use Mojo::Transaction::HTTP;
@@ -26,9 +25,8 @@ use constant {
   PONG         => 10
 };
 
-has [qw(compressed masked)];
-has context_takeover   => 1;
-has handshake          => sub { Mojo::Transaction::HTTP->new };
+has 'masked';
+has handshake => sub { Mojo::Transaction::HTTP->new };
 has max_websocket_size => sub { $ENV{MOJO_MAX_WEBSOCKET_SIZE} || 262144 };
 
 sub build_frame {
@@ -90,29 +88,13 @@ sub build_message {
   if (exists $frame->{text}) { $frame = [1, 0, 0, 0, TEXT, $frame->{text}] }
   else { $frame = [1, 0, 0, 0, BINARY, $frame->{binary}] }
 
-  # "permessage-deflate" extension
-  return $self->build_frame(@$frame) unless $self->compressed;
-  my $deflate = $self->{deflate}
-    || Compress::Raw::Zlib::Deflate->new(WindowBits => -15, MemLevel => 8);
-  $self->{deflate} = $deflate if $self->context_takeover;
-  $deflate->deflate(\$frame->[5], my $out);
-  $deflate->flush($out, Z_SYNC_FLUSH);
-  @$frame[1, 5] = (1, substr($out, 0, length($out) - 4));
   return $self->build_frame(@$frame);
 }
 
 sub client_challenge {
   my $self = shift;
-
-  # "permessage-deflate" extension
-  my $headers = $self->res->headers;
-  my $extensions = $headers->sec_websocket_extensions // '';
-  $self->context_takeover(0)
-    if $self->_deflate($extensions)
-    && $extensions =~ /client_no_context_takeover/i;
-
   return _challenge($self->req->headers->sec_websocket_key) eq
-    $headers->sec_websocket_accept;
+    $self->res->headers->sec_websocket_accept;
 }
 
 sub client_handshake {
@@ -122,8 +104,6 @@ sub client_handshake {
   $headers->upgrade('websocket')      unless $headers->upgrade;
   $headers->connection('Upgrade')     unless $headers->connection;
   $headers->sec_websocket_version(13) unless $headers->sec_websocket_version;
-  $headers->sec_websocket_extensions('permessage-deflate')
-    unless $headers->sec_websocket_extensions;
 
   # Generate 16 byte WebSocket challenge
   my $challenge = b64_encode sprintf('%16u', int(rand 9 x 16)), '';
@@ -259,10 +239,6 @@ sub server_handshake {
     and $res_headers->sec_websocket_protocol($1);
   $res_headers->sec_websocket_accept(
     _challenge($req_headers->sec_websocket_key));
-
-  # "permessage-deflate" extension
-  $res_headers->sec_websocket_extensions('permessage-deflate')
-    if $self->_deflate($req_headers->sec_websocket_extensions // '');
 }
 
 sub server_read {
@@ -289,8 +265,6 @@ sub server_write {
 
 sub _challenge { b64_encode(sha1_bytes(($_[0] || '') . GUID), '') }
 
-sub _deflate { $_[1] =~ /permessage-deflate/i && $_[0]->compressed(1) }
-
 sub _message {
   my ($self, $frame) = @_;
 
@@ -317,20 +291,7 @@ sub _message {
   # No FIN bit (Continuation)
   return unless $frame->[0];
 
-  # "permessage-deflate" extension (handshake and RSV1)
   my $msg = delete $self->{message};
-  if ($self->compressed && $frame->[1]) {
-    my $inflate = $self->{inflate} || Compress::Raw::Zlib::Inflate->new(
-      Bufsize     => $max,
-      LimitOutput => 1,
-      WindowBits  => -15
-    );
-    $self->{inflate} = $inflate if $self->context_takeover;
-    $inflate->inflate(\($msg .= "\x00\x00\xff\xff"), my $out);
-    return $self->finish(1009) if length $msg;
-    $msg = $out;
-  }
-
   $self->emit(json => Mojo::JSON->new->decode($msg))
     if $self->has_subscribers('json');
   $op = delete $self->{op};
@@ -482,21 +443,6 @@ Emitted when a complete WebSocket text message has been received.
 L<Mojo::Transaction::WebSocket> inherits all attributes from
 L<Mojo::Transaction> and implements the following new ones.
 
-=head2 compressed
-
-  my $bool = $ws->compressed;
-  $ws      = $ws->compressed($bool);
-
-Compress messages with C<permessage-deflate> extension.
-
-=head2 context_takeover
-
-  my $bool = $ws->context_takeover;
-  $ws      = $ws->context_takeover($bool);
-
-Reuse LZ77 sliding window for C<permessage-deflate> extension, defaults to
-true.
-
 =head2 handshake
 
   my $handshake = $ws->handshake;
