@@ -139,7 +139,7 @@ Mojo::UserAgent::CookieJar - Cookie jar for HTTP user agents
 =head1 DESCRIPTION
 
 L<Mojo::UserAgent::CookieJar> is a minimalistic and relaxed cookie jar based
-on L<RFC 6265|http://tools.ietf.org/search/rfc6265> for L<Mojo::UserAgent>.
+on L<RFC 6265|http://tools.ietf.org/html/rfc6265> for L<Mojo::UserAgent>.
 
 =head1 ATTRIBUTES
 
